---
title: '[공지] (구)토스페이먼츠 결제사 정산 업데이트 오류 안내 (조치완료)'
category: 공지사항
seo:
  title: ''
  description: >
    안녕하세요. 포트원 고객지원팀입니다

    현재 당사의 결제사 정산 서비스 중 (구)토스페이먼츠의 정산 데이터를 수집하는 과정에서 4월 정산 데이터가 중복으로 집계되는 이슈가
    발생하여 공지드립니다.
tags:
  - 공지사항
datetime: 2024-04-30T02:23:58.602Z
---

안녕하세요. 포트원 고객지원팀입니다

현재 당사의 결제사 정산 서비스 중 (구)토스페이먼츠의 정산 데이터를 수집하는 과정에서 4월 정산 데이터가 중복으로 집계되는 이슈가 발생하여 공지드립니다.

---

- 이슈 내용 : **(구)토스페이먼츠** 정산데이터가 중복 수집되어 노출
- 해당 날짜 : 2024.04.01-2024.04.30
- 작업 일정 : 2024.04.30-2024.05.01 (내부 작업으로 인하여 (구)토스페이먼츠 정산 데이터 조회 불가)
- 재개 일정 : 2024.05.02

서비스 이용에 불편 드려 죄송합니다.

감사합니다.
